@@ -4,11 +4,11 @@
 
 ;; Author: Alvaro Ramirez https://xenodium.com
 ;; URL: https://github.com/xenodium/acp.el
-;; Package-Version: 20260215.2309
-;; Package-Revision: b9bc89948bb1
+;; Package-Version: 20260219.1624
+;; Package-Revision: 784b00017262
 ;; Package-Requires: ((emacs "28.1"))
 
-(defconst acp-package-version "0.10.1")
+(defconst acp-package-version "0.11.1")
 
 ;; This package is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -51,7 +51,7 @@
 
 (cl-defun acp-make-client (&key context-buffer command command-params environment-variables
                                 request-sender notification-sender request-resolver
-                                response-sender)
+                                response-sender outgoing-request-decorator)
   "Create an ACP client.
 
 This returns a alist representing the client.
@@ -69,7 +69,13 @@ COMMAND-PARAMS is a list of strings for command arguments.
 ENVIRONMENT-VARIABLES is a list of strings in the form \"VAR=foo\".
 
 REQUEST-SENDER, NOTIFICATION-SENDER, REQUEST-RESOLVER, and RESPONSE-SENDER are
-functions for advanced customization or testing."
+functions for advanced customization or testing.
+
+OUTGOING-REQUEST-DECORATOR is an optional function of the form
+\(lambda (request) ...) that receives the JSON-RPC request object
+before it is sent and returns a (possibly modified) request.
+If the decorator returns nil, the original request is sent and
+the error is logged."
   (unless command
     (error ":command is required"))
   (list (cons :context-buffer context-buffer)
@@ -86,7 +92,8 @@ functions for advanced customization or testing."
         (cons :request-sender (or request-sender #'acp--request-sender))
         (cons :notification-sender (or notification-sender #'acp--notification-sender))
         (cons :request-resolver (or request-resolver #'acp--request-resolver))
-        (cons :response-sender (or response-sender #'acp--response-sender))))
+        (cons :response-sender (or response-sender #'acp--response-sender))
+        (cons :outgoing-request-decorator outgoing-request-decorator)))
 
 (defun acp--client-started-p (client)
   "Return non-nil if CLIENT process has been started."
@@ -321,6 +328,12 @@ SYNC: When non-nil, send request synchronously."
     (error ":request is required"))
   (unless (acp--client-started-p client)
     (acp--start-client :client client))
+  (when-let ((decorator (map-elt client :outgoing-request-decorator)))
+    (if-let ((decorated (funcall decorator request)))
+        (setq request decorated)
+      (acp--log client "DECORATOR ERROR"
+                "Outgoing request decorator returned nil for \"%s\", sending original request"
+                (map-elt request :method))))
   (let* ((method (map-elt request :method))
          (params (map-elt request :params))
          (proc (map-elt client :process))
